import { copyToClipboard, QVueGlobals, useQuasar } from 'quasar'


/**
 * 复制文本
 * @param string
 */
function copy(string: string, $q: QVueGlobals) {

  copyToClipboard(string)
    .then(() => {

      // success!
      $q.notify({
        message: '复制成功',
        color: 'positive',
        position: 'top'
      })
    })
    .catch(() => {

      // fail
      $q.notify({
        message: '复制失败',
        color: 'negative'
      })
    })
}
/**
 *根据延迟计算颜色
 * @param bili 数值 延迟单位ms
 * @returns
 */
function getColorForDelay(delay: number): string {
  // 限制延迟在200到2000之间
  const clampedDelay = Math.min(Math.max(delay, 200), 2000);

  // 将延迟从[200, 2000]映射到[0, 1]
  const normalizedDelay = (clampedDelay - 200) / (2000 - 200);

  // 计算从绿色到红色的颜色变化
  const green = 255 - normalizedDelay * 255;
  const red = normalizedDelay * 255;

  // 返回 RGB 颜色格式
  return `rgb(${Math.round(red)}, ${Math.round(green)}, 0)`;
}

/**
 * 根据延迟计算颜色 就三种颜色
 * @param bili
 * @returns
 */
function signal_style(bili: number) {
  let tmp = ''
  if (bili >= 0 && bili <= 700) {
    tmp = 'green'
  } else if (bili > 700 && bili < 1400) {
    tmp = '#FF9800'
  } else {
    tmp = 'red'
  }
  return tmp
}
const is_ip = (ip: string) => {
  const reg = /^(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])$/
  return reg.test(ip);
}
function extractIPv4(ip: string): string | null {
  const ipv4Regex = /(\b25[0-5]\b|\b2[0-4][0-9]\b|\b[01]?[0-9][0-9]?\b)\.(\b25[0-5]\b|\b2[0-4][0-9]\b|\b[01]?[0-9][0-9]?\b)\.(\b25[0-5]\b|\b2[0-4][0-9]\b|\b[01]?[0-9][0-9]?\b)\.(\b25[0-5]\b|\b2[0-4][0-9]\b|\b[01]?[0-9][0-9]?\b)/g;
  const matches = ip.match(ipv4Regex);

  // 如果没有匹配到任何IPv4地址，返回 null
  if (!matches) {
    return null;
  }

  // 返回第一个匹配到的IPv4地址
  return matches[0];
}

export { copy, getColorForDelay, signal_style, is_ip, extractIPv4 }
